@@ -1,7 +1,6 @@
 from typing import Optional
 
 from ..scripture.verse_ref import Versification
-from ..tokenization.tokenizer import Tokenizer
 from ..utils.typeshed import StrPath
 from .stream_container import StreamContainer
 from .usx_text_base import UsxTextBase
@@ -11,13 +10,12 @@ from .zip_entry_stream_container import ZipEntryStreamContainer
 class DblBundleText(UsxTextBase):
     def __init__(
         self,
-        word_tokenizer: Tokenizer[str, int, str],
         id: str,
         bundle_filename: StrPath,
         path: str,
         versification: Optional[Versification] = None,
     ) -> None:
-        super().__init__(word_tokenizer, id, versification)
+        super().__init__(id, versification)
 
         self._bundle_filename = bundle_filename
         self._path = path
