@@ -1,25 +1,23 @@
 from pathlib import Path
-from typing import Generator, Optional
+from typing import Generator, List, Union
 
-from ..tokenization.tokenizer import Tokenizer
 from ..utils.string_utils import is_integer
 from ..utils.typeshed import StrPath
-from .text import Text
+from .row_ref import RowRef
 from .text_base import TextBase
-from .text_segment import TextSegment
-from .text_segment_ref import TextSegmentRef
+from .text_row import TextRow
 
 
 class TextFileText(TextBase):
-    def __init__(self, word_tokenizer: Tokenizer[str, int, str], id: str, filename: StrPath) -> None:
-        super().__init__(word_tokenizer, id, id)
+    def __init__(self, id: str, filename: StrPath) -> None:
+        super().__init__(id, id)
         self._filename = Path(filename)
 
     @property
     def filename(self) -> Path:
         return self._filename
 
-    def _get_segments(self, include_text: bool, sort_based_on: Optional[Text]) -> Generator[TextSegment, None, None]:
+    def _get_rows(self) -> Generator[TextRow, None, None]:
         with open(self._filename, "r", encoding="utf-8-sig") as file:
             section_num = 1
             segment_num = 1
@@ -31,5 +29,18 @@ class TextFileText(TextBase):
                         section_num = int(section_num_str)
                         segment_num = 1
                 else:
-                    yield self._create_text_segment(include_text, line, TextSegmentRef(section_num, segment_num))
+                    keys: List[Union[str, int]] = []
+                    if self.id != "*all*":
+                        keys.append(self.id)
+                    keys.append(section_num)
+                    keys.append(segment_num)
+                    yield self._create_row(line, RowRef(keys))
                     segment_num += 1
+
+    @property
+    def missing_rows_allowed(self) -> bool:
+        return False
+
+    def count(self, include_empty: bool = True) -> int:
+        with open(self._filename, mode="rb") as file:
+            return sum(1 for line in file if include_empty or len(line.strip()) > 0)
