@@ -1,7 +1,7 @@
 from dataclasses import dataclass
 from enum import Enum, IntEnum, auto
 from pathlib import Path
-from typing import Dict, Iterable, List, Optional, Set, TextIO, Tuple, Union
+from typing import Dict, Iterable, List, Optional, Set, TextIO, Tuple, Union, cast
 
 import regex as re
 
@@ -97,8 +97,10 @@ class VerseRef(Comparable):
             raise ValueError("This start verse contains multiple verses.")
         if end.has_multiple:
             raise ValueError("This end verse contains multiple verses.")
+        if start.versification != end.versification:
+            raise ValueError("The start and end verses do not have the same versification.")
 
-        return VerseRef(start.book, start.chapter, f"{start.verse_num}-{end.verse_num}")
+        return VerseRef(start.book, start.chapter, f"{start.verse_num}-{end.verse_num}", start.versification)
 
     @classmethod
     def from_bbbcccvvv(cls, bbbcccvvv: int, versification: Optional["Versification"] = None) -> "VerseRef":
@@ -775,7 +777,7 @@ class Versification:
         )
 
     def _change_versification_with_ranges(self, vref: VerseRef) -> bool:
-        parts: List[str] = re.split(r"([,\-])", vref.verse)
+        parts = cast(List[str], re.split(r"([,\-])", vref.verse))
 
         new_vref = vref.copy()
         new_vref.verse = parts[0]
