@@ -9,6 +9,7 @@ from .symmetrized_word_alignment_model import SymmetrizedWordAlignmentModel
 from .symmetrized_word_alignment_model_trainer import SymmetrizedWordAlignmentModelTrainer
 from .trainer import Trainer, TrainStats
 from .translation_engine import TranslationEngine
+from .translation_model import TranslationModel
 from .translation_result import TranslationResult
 from .translation_result_builder import TranslationResultBuilder
 from .translation_sources import TranslationSources
@@ -29,6 +30,7 @@ __all__ = [
     "TrainStats",
     "Trainer",
     "TranslationEngine",
+    "TranslationModel",
     "TranslationResult",
     "TranslationResultBuilder",
     "TranslationSources",
