@@ -1,8 +1,6 @@
-import sys
 from typing import Collection, Iterable, Optional, Sequence, Tuple, Union
 
 from ..corpora.parallel_text_corpus import ParallelTextCorpus
-from ..corpora.token_processors import NO_OP, TokenProcessor
 from .symmetrized_word_aligner import SymmetrizedWordAligner
 from .symmetrized_word_alignment_model_trainer import SymmetrizedWordAlignmentModelTrainer
 from .trainer import Trainer
@@ -70,18 +68,8 @@ class SymmetrizedWordAlignmentModel(SymmetrizedWordAligner, WordAlignmentModel):
         )
         return max(dir_score, inv_score)
 
-    def create_trainer(
-        self,
-        corpus: ParallelTextCorpus,
-        source_preprocessor: TokenProcessor = NO_OP,
-        target_preprocessor: TokenProcessor = NO_OP,
-        max_corpus_count: int = sys.maxsize,
-    ) -> Trainer:
-        direct_trainer = self._direct_word_alignment_model.create_trainer(
-            corpus, source_preprocessor, target_preprocessor, max_corpus_count
-        )
-        inverse_trainer = self._inverse_word_alignment_model.create_trainer(
-            corpus.invert(), target_preprocessor, source_preprocessor, max_corpus_count
-        )
+    def create_trainer(self, corpus: ParallelTextCorpus) -> Trainer:
+        direct_trainer = self._direct_word_alignment_model.create_trainer(corpus)
+        inverse_trainer = self._inverse_word_alignment_model.create_trainer(corpus.invert())
 
         return SymmetrizedWordAlignmentModelTrainer(direct_trainer, inverse_trainer)
