@@ -1,4 +1,3 @@
-import sys
 from abc import abstractmethod
 from pathlib import Path
 from typing import Collection, Iterable, Iterator, Optional, Sequence, Tuple, Union
@@ -6,7 +5,6 @@ from typing import Collection, Iterable, Iterator, Optional, Sequence, Tuple, Un
 import thot.alignment as ta
 
 from ...corpora.parallel_text_corpus import ParallelTextCorpus
-from ...corpora.token_processors import NO_OP, TokenProcessor
 from ...utils.typeshed import StrPath
 from ..ibm1_word_alignment_model import Ibm1WordAlignmentModel
 from ..trainer import Trainer
@@ -69,14 +67,8 @@ class ThotWordAlignmentModel(Ibm1WordAlignmentModel):
         if self._prefix_filename is not None:
             self._model.print(str(self._prefix_filename))
 
-    def create_trainer(
-        self,
-        corpus: ParallelTextCorpus,
-        source_preprocessor: TokenProcessor = NO_OP,
-        target_preprocessor: TokenProcessor = NO_OP,
-        max_corpus_count: int = sys.maxsize,
-    ) -> Trainer:
-        return _Trainer(self, corpus, self._prefix_filename, source_preprocessor, target_preprocessor, max_corpus_count)
+    def create_trainer(self, corpus: ParallelTextCorpus) -> Trainer:
+        return _Trainer(self, corpus, self._prefix_filename)
 
     def get_best_alignment(self, source_segment: Sequence[str], target_segment: Sequence[str]) -> WordAlignmentMatrix:
         _, matrix = self._model.get_best_alignment(source_segment, target_segment)
@@ -171,23 +163,9 @@ class _ThotWordVocabulary(WordVocabulary):
 
 class _Trainer(ThotWordAlignmentModelTrainer):
     def __init__(
-        self,
-        model: ThotWordAlignmentModel,
-        corpus: ParallelTextCorpus,
-        prefix_filename: Optional[StrPath],
-        source_preprocessor: TokenProcessor,
-        target_preprocessor: TokenProcessor,
-        max_corpus_count: int,
+        self, model: ThotWordAlignmentModel, corpus: ParallelTextCorpus, prefix_filename: Optional[StrPath]
     ) -> None:
-        super().__init__(
-            model.type,
-            corpus,
-            prefix_filename,
-            model.parameters,
-            source_preprocessor,
-            target_preprocessor,
-            max_corpus_count,
-        )
+        super().__init__(model.type, corpus, prefix_filename, model.parameters)
         self._machine_model = model
 
     def save(self) -> None:
