@@ -5,8 +5,7 @@ from typing import Callable, List, Optional, Tuple, Union, overload
 import thot.alignment as ta
 
 from ...corpora.parallel_text_corpus import ParallelTextCorpus
-from ...corpora.parallel_text_segment import ParallelTextSegment
-from ...corpora.token_processors import NO_OP, TokenProcessor
+from ...corpora.parallel_text_row import ParallelTextRow
 from ...utils.progress_status import ProgressStatus
 from ...utils.typeshed import StrPath
 from ..trainer import Trainer, TrainStats
@@ -22,8 +21,6 @@ class ThotWordAlignmentModelTrainer(Trainer):
         corpus: ParallelTextCorpus,
         prefix_filename: Optional[StrPath],
         parameters: ThotWordAlignmentParameters = ThotWordAlignmentParameters(),
-        source_preprocessor: TokenProcessor = NO_OP,
-        target_preprocessor: TokenProcessor = NO_OP,
         max_corpus_count: int = sys.maxsize,
     ) -> None:
         ...
@@ -35,8 +32,6 @@ class ThotWordAlignmentModelTrainer(Trainer):
         corpus: Tuple[StrPath, StrPath],
         prefix_filename: Optional[StrPath],
         parameters: ThotWordAlignmentParameters = ThotWordAlignmentParameters(),
-        source_preprocessor: TokenProcessor = NO_OP,
-        target_preprocessor: TokenProcessor = NO_OP,
     ) -> None:
         ...
 
@@ -46,25 +41,16 @@ class ThotWordAlignmentModelTrainer(Trainer):
         corpus: Union[ParallelTextCorpus, Tuple[StrPath, StrPath]],
         prefix_filename: Optional[StrPath],
         parameters: ThotWordAlignmentParameters = ThotWordAlignmentParameters(),
-        source_preprocessor: TokenProcessor = NO_OP,
-        target_preprocessor: TokenProcessor = NO_OP,
         max_corpus_count: int = sys.maxsize,
     ) -> None:
         if isinstance(corpus, tuple) and max_corpus_count != sys.maxsize:
             raise ValueError("max_corpus_count cannot be set when corpus filenames are provided.")
 
         self._prefix_filename = None if prefix_filename is None else Path(prefix_filename)
-        self._source_preprocessor = source_preprocessor
-        self._target_preprocessor = target_preprocessor
         self._parallel_corpus = corpus
         self._max_corpus_count = max_corpus_count
         self._stats = TrainStats()
 
-        def null_segment_filter(s: ParallelTextSegment, i: int) -> bool:
-            return True
-
-        self._segment_filter = null_segment_filter
-
         self._models: List[Tuple[ta.AlignmentModel, int]] = []
         if model_type is ThotWordAlignmentModelType.FAST_ALIGN:
             fast_align = ta.FastAlignModel()
@@ -126,16 +112,6 @@ class ThotWordAlignmentModelTrainer(Trainer):
     def stats(self) -> TrainStats:
         return self._stats
 
-    @property
-    def segment_filter(self) -> Callable[[ParallelTextSegment, int], bool]:
-        return self._segment_filter
-
-    @segment_filter.setter
-    def segment_filter(self, value: Callable[[ParallelTextSegment, int], bool]) -> None:
-        if isinstance(self._parallel_corpus, tuple):
-            raise RuntimeError("A segment filter cannot be set when corpus filenames are provided.")
-        self._segment_filter = value
-
     @property
     def _model(self) -> ta.AlignmentModel:
         return self._models[-1][0]
@@ -154,16 +130,14 @@ class ThotWordAlignmentModelTrainer(Trainer):
         if isinstance(self._parallel_corpus, ParallelTextCorpus):
             corpus_count = 0
             index = 0
-            for segment in self._parallel_corpus.segments:
-                if self._segment_filter(segment, index):
-                    source_segment = self._source_preprocessor.process(segment.source_segment)
-                    target_segment = self._target_preprocessor.process(segment.target_segment)
-                    self._model.add_sentence_pair(source_segment, target_segment, 1)
-                    if self._is_segment_valid(segment):
+            with self._parallel_corpus.get_rows() as rows:
+                for row in rows:
+                    self._model.add_sentence_pair(row.source_segment, row.target_segment, 1)
+                    if self._is_segment_valid(row):
                         corpus_count += 1
-                index += 1
-                if corpus_count == self._max_corpus_count:
-                    break
+                    index += 1
+                    if corpus_count == self._max_corpus_count:
+                        break
         else:
             self._model.read_sentence_pairs(str(self._parallel_corpus[0]), str(self._parallel_corpus[1]))
         cur_step += 1
@@ -198,9 +172,9 @@ class ThotWordAlignmentModelTrainer(Trainer):
         if self._prefix_filename is not None:
             self._model.print(str(self._prefix_filename))
 
-    def _is_segment_valid(self, segment: ParallelTextSegment) -> bool:
+    def _is_segment_valid(self, row: ParallelTextRow) -> bool:
         return (
-            not segment.is_empty
-            and len(segment.source_segment) <= self._max_segment_length
-            and len(segment.target_segment) <= self._max_segment_length
+            not row.is_empty
+            and len(row.source_segment) <= self._max_segment_length
+            and len(row.target_segment) <= self._max_segment_length
         )
