@@ -1,21 +1,21 @@
-from typing import Callable, Collection, Iterable, List, Optional, Sequence, Set, Tuple
+from typing import Callable, Collection, Iterable, List, Optional, Sequence, Set, Tuple, cast
 
 import numpy as np
 from sortedcontainers import SortedSet
 
 from ..corpora.aligned_word_pair import AlignedWordPair
-from ..corpora.parallel_text_segment import ParallelTextSegment
+from ..corpora.parallel_text_row import ParallelTextRow
 from .symmetrization_heuristic import SymmetrizationHeuristic
 
 
 class WordAlignmentMatrix:
     @classmethod
-    def from_parallel_text_segment(cls, segment: ParallelTextSegment) -> Optional["WordAlignmentMatrix"]:
-        if segment.aligned_word_pairs is None:
+    def from_parallel_text_corpus_row(cls, row: ParallelTextRow) -> Optional["WordAlignmentMatrix"]:
+        if row.aligned_word_pairs is None:
             return None
 
-        matrix = cls.from_word_pairs(len(segment.source_segment), len(segment.target_segment))
-        for word_pair in segment.aligned_word_pairs:
+        matrix = cls.from_word_pairs(len(row.source_segment), len(row.target_segment))
+        for word_pair in row.aligned_word_pairs:
             matrix[word_pair.source_index, word_pair.target_index] = True
         return matrix
 
@@ -312,7 +312,7 @@ class WordAlignmentMatrix:
     def _koehn_grow(
         self, grow_condition: Callable[[int, int], bool], orig: "WordAlignmentMatrix", other: "WordAlignmentMatrix"
     ) -> None:
-        p = SortedSet()
+        p = cast(Set[Tuple[int, int]], SortedSet())
         for i in range(self.row_count):
             for j in range(self.column_count):
                 if (orig[i, j] or other[i, j]) and not self[i, j]:
@@ -321,7 +321,7 @@ class WordAlignmentMatrix:
         keep_going = len(p) > 0
         while keep_going:
             keep_going = False
-            added = SortedSet()
+            added = cast(Set[Tuple[int, int]], SortedSet())
             for i, j in p:
                 if (not self.is_row_aligned(i) or not self.is_column_aligned(j)) and grow_condition(i, j):
                     self[i, j] = True
